/*
  Copyright (c) 2015, Matthias Schiffer <mschiffer@universe-factory.net>
  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:

    1. Redistributions of source code must retain the above copyright notice,
       this list of conditions and the following disclaimer.
    2. Redistributions in binary form must reproduce the above copyright notice,
       this list of conditions and the following disclaimer in the documentation
       and/or other materials provided with the distribution.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#include "BlockType.hpp"


namespace MinedMap {
namespace Resource {

const BlockType BLOCK_TYPES[256][16] = {
	{ /* 0 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 1 */
		{true,  false, 0x7d7d7d},
		{true,  false, 0x997162},
		{true,  false, 0x9f7262},
		{true,  false, 0xb3b3b6},
		{true,  false, 0xb7b7b9},
		{true,  false, 0x828383},
		{true,  false, 0x858586},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 2 */
		{true,  true,  0x939393},
		{true,  true,  0x939393},
		{true,  true,  0x939393},
		{true,  true,  0x939393},
		{true,  true,  0x939393},
		{true,  true,  0x939393},
		{true,  true,  0x939393},
		{true,  true,  0x939393},
		{true,  true,  0x939393},
		{true,  true,  0x939393},
		{true,  true,  0x939393},
		{true,  true,  0x939393},
		{true,  true,  0x939393},
		{true,  true,  0x939393},
		{true,  true,  0x939393},
		{true,  true,  0x939393},
	},
	{ /* 3 */
		{true,  false, 0x866043},
		{true,  false, 0x866043},
		{true,  false, 0x5a3f1c},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 4 */
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
	},
	{ /* 5 */
		{true,  false, 0x9c7f4e},
		{true,  false, 0x674d2e},
		{true,  false, 0xc3b37b},
		{true,  false, 0x9a6e4d},
		{true,  false, 0xa95b33},
		{true,  false, 0x3d2712},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 6 */
		{true,  false, 0x476625},
		{true,  false, 0x333a21},
		{true,  false, 0x769654},
		{true,  false, 0x305612},
		{true,  false, 0x727314},
		{true,  false, 0x38561c},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{true,  false, 0x476625},
		{true,  false, 0x333a21},
		{true,  false, 0x769654},
		{true,  false, 0x305612},
		{true,  false, 0x727314},
		{true,  false, 0x38561c},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 7 */
		{true,  false, 0x535353},
		{true,  false, 0x535353},
		{true,  false, 0x535353},
		{true,  false, 0x535353},
		{true,  false, 0x535353},
		{true,  false, 0x535353},
		{true,  false, 0x535353},
		{true,  false, 0x535353},
		{true,  false, 0x535353},
		{true,  false, 0x535353},
		{true,  false, 0x535353},
		{true,  false, 0x535353},
		{true,  false, 0x535353},
		{true,  false, 0x535353},
		{true,  false, 0x535353},
		{true,  false, 0x535353},
	},
	{ /* 8 */
		{true,  false, 0x3147f4},
		{true,  false, 0x3147f4},
		{true,  false, 0x3147f4},
		{true,  false, 0x3147f4},
		{true,  false, 0x3147f4},
		{true,  false, 0x3147f4},
		{true,  false, 0x3147f4},
		{true,  false, 0x3147f4},
		{true,  false, 0x3147f4},
		{true,  false, 0x3147f4},
		{true,  false, 0x3147f4},
		{true,  false, 0x3147f4},
		{true,  false, 0x3147f4},
		{true,  false, 0x3147f4},
		{true,  false, 0x3147f4},
		{true,  false, 0x3147f4},
	},
	{ /* 9 */
		{true,  false, 0x2e43f4},
		{true,  false, 0x2e43f4},
		{true,  false, 0x2e43f4},
		{true,  false, 0x2e43f4},
		{true,  false, 0x2e43f4},
		{true,  false, 0x2e43f4},
		{true,  false, 0x2e43f4},
		{true,  false, 0x2e43f4},
		{true,  false, 0x2e43f4},
		{true,  false, 0x2e43f4},
		{true,  false, 0x2e43f4},
		{true,  false, 0x2e43f4},
		{true,  false, 0x2e43f4},
		{true,  false, 0x2e43f4},
		{true,  false, 0x2e43f4},
		{true,  false, 0x2e43f4},
	},
	{ /* 10 */
		{true,  false, 0xcf5b13},
		{true,  false, 0xcf5b13},
		{true,  false, 0xcf5b13},
		{true,  false, 0xcf5b13},
		{true,  false, 0xcf5b13},
		{true,  false, 0xcf5b13},
		{true,  false, 0xcf5b13},
		{true,  false, 0xcf5b13},
		{true,  false, 0xcf5b13},
		{true,  false, 0xcf5b13},
		{true,  false, 0xcf5b13},
		{true,  false, 0xcf5b13},
		{true,  false, 0xcf5b13},
		{true,  false, 0xcf5b13},
		{true,  false, 0xcf5b13},
		{true,  false, 0xcf5b13},
	},
	{ /* 11 */
		{true,  false, 0xd45a12},
		{true,  false, 0xd45a12},
		{true,  false, 0xd45a12},
		{true,  false, 0xd45a12},
		{true,  false, 0xd45a12},
		{true,  false, 0xd45a12},
		{true,  false, 0xd45a12},
		{true,  false, 0xd45a12},
		{true,  false, 0xd45a12},
		{true,  false, 0xd45a12},
		{true,  false, 0xd45a12},
		{true,  false, 0xd45a12},
		{true,  false, 0xd45a12},
		{true,  false, 0xd45a12},
		{true,  false, 0xd45a12},
		{true,  false, 0xd45a12},
	},
	{ /* 12 */
		{true,  false, 0xdbd3a0},
		{true,  false, 0xa95821},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 13 */
		{true,  false, 0x7e7c7a},
		{true,  false, 0x7e7c7a},
		{true,  false, 0x7e7c7a},
		{true,  false, 0x7e7c7a},
		{true,  false, 0x7e7c7a},
		{true,  false, 0x7e7c7a},
		{true,  false, 0x7e7c7a},
		{true,  false, 0x7e7c7a},
		{true,  false, 0x7e7c7a},
		{true,  false, 0x7e7c7a},
		{true,  false, 0x7e7c7a},
		{true,  false, 0x7e7c7a},
		{true,  false, 0x7e7c7a},
		{true,  false, 0x7e7c7a},
		{true,  false, 0x7e7c7a},
		{true,  false, 0x7e7c7a},
	},
	{ /* 14 */
		{true,  false, 0x8f8b7c},
		{true,  false, 0x8f8b7c},
		{true,  false, 0x8f8b7c},
		{true,  false, 0x8f8b7c},
		{true,  false, 0x8f8b7c},
		{true,  false, 0x8f8b7c},
		{true,  false, 0x8f8b7c},
		{true,  false, 0x8f8b7c},
		{true,  false, 0x8f8b7c},
		{true,  false, 0x8f8b7c},
		{true,  false, 0x8f8b7c},
		{true,  false, 0x8f8b7c},
		{true,  false, 0x8f8b7c},
		{true,  false, 0x8f8b7c},
		{true,  false, 0x8f8b7c},
		{true,  false, 0x8f8b7c},
	},
	{ /* 15 */
		{true,  false, 0x87827e},
		{true,  false, 0x87827e},
		{true,  false, 0x87827e},
		{true,  false, 0x87827e},
		{true,  false, 0x87827e},
		{true,  false, 0x87827e},
		{true,  false, 0x87827e},
		{true,  false, 0x87827e},
		{true,  false, 0x87827e},
		{true,  false, 0x87827e},
		{true,  false, 0x87827e},
		{true,  false, 0x87827e},
		{true,  false, 0x87827e},
		{true,  false, 0x87827e},
		{true,  false, 0x87827e},
		{true,  false, 0x87827e},
	},
	{ /* 16 */
		{true,  false, 0x737373},
		{true,  false, 0x737373},
		{true,  false, 0x737373},
		{true,  false, 0x737373},
		{true,  false, 0x737373},
		{true,  false, 0x737373},
		{true,  false, 0x737373},
		{true,  false, 0x737373},
		{true,  false, 0x737373},
		{true,  false, 0x737373},
		{true,  false, 0x737373},
		{true,  false, 0x737373},
		{true,  false, 0x737373},
		{true,  false, 0x737373},
		{true,  false, 0x737373},
		{true,  false, 0x737373},
	},
	{ /* 17 */
		{true,  false, 0x9a7d4d},
		{true,  false, 0x685130},
		{true,  false, 0xb8a679},
		{true,  false, 0x997649},
		{true,  false, 0x665131},
		{true,  false, 0x2d1c0c},
		{true,  false, 0xcecec9},
		{true,  false, 0x57431a},
		{true,  false, 0x665131},
		{true,  false, 0x2d1c0c},
		{true,  false, 0xcecec9},
		{true,  false, 0x57431a},
		{true,  false, 0x665131},
		{true,  false, 0x2d1c0c},
		{true,  false, 0xcecec9},
		{true,  false, 0x57431a},
	},
	{ /* 18 */
		{true,  true,  0x878787},
		{true,  true,  0x747474},
		{true,  true,  0x878787},
		{true,  true,  0x918e86},
		{true,  true,  0x878787},
		{true,  true,  0x747474},
		{true,  true,  0x878787},
		{true,  true,  0x918e86},
		{true,  true,  0x878787},
		{true,  true,  0x747474},
		{true,  true,  0x878787},
		{true,  true,  0x918e86},
		{true,  true,  0x878787},
		{true,  true,  0x747474},
		{true,  true,  0x878787},
		{true,  true,  0x918e86},
	},
	{ /* 19 */
		{true,  false, 0xc2c354},
		{true,  false, 0xc2c354},
		{true,  false, 0xc2c354},
		{true,  false, 0xc2c354},
		{true,  false, 0xc2c354},
		{true,  false, 0xc2c354},
		{true,  false, 0xc2c354},
		{true,  false, 0xc2c354},
		{true,  false, 0xc2c354},
		{true,  false, 0xc2c354},
		{true,  false, 0xc2c354},
		{true,  false, 0xc2c354},
		{true,  false, 0xc2c354},
		{true,  false, 0xc2c354},
		{true,  false, 0xc2c354},
		{true,  false, 0xc2c354},
	},
	{ /* 20 */
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
	},
	{ /* 21 */
		{true,  false, 0x667086},
		{true,  false, 0x667086},
		{true,  false, 0x667086},
		{true,  false, 0x667086},
		{true,  false, 0x667086},
		{true,  false, 0x667086},
		{true,  false, 0x667086},
		{true,  false, 0x667086},
		{true,  false, 0x667086},
		{true,  false, 0x667086},
		{true,  false, 0x667086},
		{true,  false, 0x667086},
		{true,  false, 0x667086},
		{true,  false, 0x667086},
		{true,  false, 0x667086},
		{true,  false, 0x667086},
	},
	{ /* 22 */
		{true,  false, 0x264389},
		{true,  false, 0x264389},
		{true,  false, 0x264389},
		{true,  false, 0x264389},
		{true,  false, 0x264389},
		{true,  false, 0x264389},
		{true,  false, 0x264389},
		{true,  false, 0x264389},
		{true,  false, 0x264389},
		{true,  false, 0x264389},
		{true,  false, 0x264389},
		{true,  false, 0x264389},
		{true,  false, 0x264389},
		{true,  false, 0x264389},
		{true,  false, 0x264389},
		{true,  false, 0x264389},
	},
	{ /* 23 */
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
	},
	{ /* 24 */
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
	},
	{ /* 25 */
		{true,  false, 0x644332},
		{true,  false, 0x644332},
		{true,  false, 0x644332},
		{true,  false, 0x644332},
		{true,  false, 0x644332},
		{true,  false, 0x644332},
		{true,  false, 0x644332},
		{true,  false, 0x644332},
		{true,  false, 0x644332},
		{true,  false, 0x644332},
		{true,  false, 0x644332},
		{true,  false, 0x644332},
		{true,  false, 0x644332},
		{true,  false, 0x644332},
		{true,  false, 0x644332},
		{true,  false, 0x644332},
	},
	{ /* 26 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 27 */
		{true,  false, 0x846c48},
		{true,  false, 0x846c48},
		{true,  false, 0x846c48},
		{true,  false, 0x846c48},
		{true,  false, 0x846c48},
		{true,  false, 0x846c48},
		{true,  false, 0x846c48},
		{true,  false, 0x846c48},
		{true,  false, 0x846c48},
		{true,  false, 0x846c48},
		{true,  false, 0x846c48},
		{true,  false, 0x846c48},
		{true,  false, 0x846c48},
		{true,  false, 0x846c48},
		{true,  false, 0x846c48},
		{true,  false, 0x846c48},
	},
	{ /* 28 */
		{true,  false, 0x786559},
		{true,  false, 0x786559},
		{true,  false, 0x786559},
		{true,  false, 0x786559},
		{true,  false, 0x786559},
		{true,  false, 0x786559},
		{true,  false, 0x786559},
		{true,  false, 0x786559},
		{true,  false, 0x786559},
		{true,  false, 0x786559},
		{true,  false, 0x786559},
		{true,  false, 0x786559},
		{true,  false, 0x786559},
		{true,  false, 0x786559},
		{true,  false, 0x786559},
		{true,  false, 0x786559},
	},
	{ /* 29 */
		{true,  false, 0x606060},
		{true,  false, 0x8d9263},
		{true,  false, 0x6a665f},
		{true,  false, 0x6a665f},
		{true,  false, 0x6a665f},
		{true,  false, 0x6a665f},
		{true,  false, 0x8d9263},
		{false, false, 0x000000},
		{true,  false, 0x606060},
		{true,  false, 0x8d9263},
		{true,  false, 0x6a665f},
		{true,  false, 0x6a665f},
		{true,  false, 0x6a665f},
		{true,  false, 0x6a665f},
		{true,  false, 0x8d9263},
		{false, false, 0x000000},
	},
	{ /* 30 */
		{true,  false, 0xdcdcdc},
		{true,  false, 0xdcdcdc},
		{true,  false, 0xdcdcdc},
		{true,  false, 0xdcdcdc},
		{true,  false, 0xdcdcdc},
		{true,  false, 0xdcdcdc},
		{true,  false, 0xdcdcdc},
		{true,  false, 0xdcdcdc},
		{true,  false, 0xdcdcdc},
		{true,  false, 0xdcdcdc},
		{true,  false, 0xdcdcdc},
		{true,  false, 0xdcdcdc},
		{true,  false, 0xdcdcdc},
		{true,  false, 0xdcdcdc},
		{true,  false, 0xdcdcdc},
		{true,  false, 0xdcdcdc},
	},
	{ /* 31 */
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
	},
	{ /* 32 */
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
		{false, true,  0x000000},
	},
	{ /* 33 */
		{true,  false, 0x606060},
		{true,  false, 0x998159},
		{true,  false, 0x6a665f},
		{true,  false, 0x6a665f},
		{true,  false, 0x6a665f},
		{true,  false, 0x6a665f},
		{true,  false, 0x998159},
		{false, false, 0x000000},
		{true,  false, 0x606060},
		{true,  false, 0x998159},
		{true,  false, 0x6a665f},
		{true,  false, 0x6a665f},
		{true,  false, 0x6a665f},
		{true,  false, 0x6a665f},
		{true,  false, 0x998159},
		{false, false, 0x000000},
	},
	{ /* 34 */
		{true,  false, 0x998159},
		{true,  false, 0x998159},
		{true,  false, 0x998159},
		{true,  false, 0x998159},
		{true,  false, 0x998159},
		{true,  false, 0x998159},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{true,  false, 0x8d9263},
		{true,  false, 0x8d9263},
		{true,  false, 0x8d9263},
		{true,  false, 0x8d9263},
		{true,  false, 0x8d9263},
		{true,  false, 0x8d9263},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 35 */
		{true,  false, 0xe9ecec},
		{true,  false, 0xf07613},
		{true,  false, 0xbd44b3},
		{true,  false, 0x3aafd9},
		{true,  false, 0xf8c527},
		{true,  false, 0x70b919},
		{true,  false, 0xed8dac},
		{true,  false, 0x3e4447},
		{true,  false, 0x8e8e86},
		{true,  false, 0x158991},
		{true,  false, 0x792aac},
		{true,  false, 0x35399d},
		{true,  false, 0x724728},
		{true,  false, 0x546d1b},
		{true,  false, 0xa02722},
		{true,  false, 0x141519},
	},
	{ /* 36 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 37 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 38 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 39 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 40 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 41 */
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
	},
	{ /* 42 */
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
	},
	{ /* 43 */
		{true,  false, 0x9f9f9f},
		{true,  false, 0xdad29e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x926356},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x2c161a},
		{true,  false, 0xece9e2},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 44 */
		{true,  false, 0x9f9f9f},
		{true,  false, 0xdad29e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x926356},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x2c161a},
		{true,  false, 0xece9e2},
		{true,  false, 0x9f9f9f},
		{true,  false, 0xdad29e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x926356},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x2c161a},
		{true,  false, 0xece9e2},
	},
	{ /* 45 */
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
	},
	{ /* 46 */
		{true,  false, 0x82412f},
		{true,  false, 0x82412f},
		{true,  false, 0x82412f},
		{true,  false, 0x82412f},
		{true,  false, 0x82412f},
		{true,  false, 0x82412f},
		{true,  false, 0x82412f},
		{true,  false, 0x82412f},
		{true,  false, 0x82412f},
		{true,  false, 0x82412f},
		{true,  false, 0x82412f},
		{true,  false, 0x82412f},
		{true,  false, 0x82412f},
		{true,  false, 0x82412f},
		{true,  false, 0x82412f},
		{true,  false, 0x82412f},
	},
	{ /* 47 */
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
	},
	{ /* 48 */
		{true,  false, 0x677967},
		{true,  false, 0x677967},
		{true,  false, 0x677967},
		{true,  false, 0x677967},
		{true,  false, 0x677967},
		{true,  false, 0x677967},
		{true,  false, 0x677967},
		{true,  false, 0x677967},
		{true,  false, 0x677967},
		{true,  false, 0x677967},
		{true,  false, 0x677967},
		{true,  false, 0x677967},
		{true,  false, 0x677967},
		{true,  false, 0x677967},
		{true,  false, 0x677967},
		{true,  false, 0x677967},
	},
	{ /* 49 */
		{true,  false, 0x14121d},
		{true,  false, 0x14121d},
		{true,  false, 0x14121d},
		{true,  false, 0x14121d},
		{true,  false, 0x14121d},
		{true,  false, 0x14121d},
		{true,  false, 0x14121d},
		{true,  false, 0x14121d},
		{true,  false, 0x14121d},
		{true,  false, 0x14121d},
		{true,  false, 0x14121d},
		{true,  false, 0x14121d},
		{true,  false, 0x14121d},
		{true,  false, 0x14121d},
		{true,  false, 0x14121d},
		{true,  false, 0x14121d},
	},
	{ /* 50 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 51 */
		{true,  false, 0xd38c35},
		{true,  false, 0xd38c35},
		{true,  false, 0xd38c35},
		{true,  false, 0xd38c35},
		{true,  false, 0xd38c35},
		{true,  false, 0xd38c35},
		{true,  false, 0xd38c35},
		{true,  false, 0xd38c35},
		{true,  false, 0xd38c35},
		{true,  false, 0xd38c35},
		{true,  false, 0xd38c35},
		{true,  false, 0xd38c35},
		{true,  false, 0xd38c35},
		{true,  false, 0xd38c35},
		{true,  false, 0xd38c35},
		{true,  false, 0xd38c35},
	},
	{ /* 52 */
		{true,  false, 0x1a2731},
		{true,  false, 0x1a2731},
		{true,  false, 0x1a2731},
		{true,  false, 0x1a2731},
		{true,  false, 0x1a2731},
		{true,  false, 0x1a2731},
		{true,  false, 0x1a2731},
		{true,  false, 0x1a2731},
		{true,  false, 0x1a2731},
		{true,  false, 0x1a2731},
		{true,  false, 0x1a2731},
		{true,  false, 0x1a2731},
		{true,  false, 0x1a2731},
		{true,  false, 0x1a2731},
		{true,  false, 0x1a2731},
		{true,  false, 0x1a2731},
	},
	{ /* 53 */
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
	},
	{ /* 54 */
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
	},
	{ /* 55 */
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
	},
	{ /* 56 */
		{true,  false, 0x818c8f},
		{true,  false, 0x818c8f},
		{true,  false, 0x818c8f},
		{true,  false, 0x818c8f},
		{true,  false, 0x818c8f},
		{true,  false, 0x818c8f},
		{true,  false, 0x818c8f},
		{true,  false, 0x818c8f},
		{true,  false, 0x818c8f},
		{true,  false, 0x818c8f},
		{true,  false, 0x818c8f},
		{true,  false, 0x818c8f},
		{true,  false, 0x818c8f},
		{true,  false, 0x818c8f},
		{true,  false, 0x818c8f},
		{true,  false, 0x818c8f},
	},
	{ /* 57 */
		{true,  false, 0x61dbd5},
		{true,  false, 0x61dbd5},
		{true,  false, 0x61dbd5},
		{true,  false, 0x61dbd5},
		{true,  false, 0x61dbd5},
		{true,  false, 0x61dbd5},
		{true,  false, 0x61dbd5},
		{true,  false, 0x61dbd5},
		{true,  false, 0x61dbd5},
		{true,  false, 0x61dbd5},
		{true,  false, 0x61dbd5},
		{true,  false, 0x61dbd5},
		{true,  false, 0x61dbd5},
		{true,  false, 0x61dbd5},
		{true,  false, 0x61dbd5},
		{true,  false, 0x61dbd5},
	},
	{ /* 58 */
		{true,  false, 0x6b472a},
		{true,  false, 0x6b472a},
		{true,  false, 0x6b472a},
		{true,  false, 0x6b472a},
		{true,  false, 0x6b472a},
		{true,  false, 0x6b472a},
		{true,  false, 0x6b472a},
		{true,  false, 0x6b472a},
		{true,  false, 0x6b472a},
		{true,  false, 0x6b472a},
		{true,  false, 0x6b472a},
		{true,  false, 0x6b472a},
		{true,  false, 0x6b472a},
		{true,  false, 0x6b472a},
		{true,  false, 0x6b472a},
		{true,  false, 0x6b472a},
	},
	{ /* 59 */
		{true,  false, 0x00b312},
		{true,  false, 0x12ac0f},
		{true,  false, 0x1c890b},
		{true,  false, 0x258b08},
		{true,  false, 0x2e8007},
		{true,  false, 0x427b07},
		{true,  false, 0x507607},
		{true,  false, 0x566607},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 60 */
		{true,  false, 0x734b2d},
		{true,  false, 0x4b280d},
		{true,  false, 0x4b280d},
		{true,  false, 0x4b280d},
		{true,  false, 0x4b280d},
		{true,  false, 0x4b280d},
		{true,  false, 0x4b280d},
		{true,  false, 0x4b280d},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 61 */
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
	},
	{ /* 62 */
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
	},
	{ /* 63 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 64 */
		{true,  false, 0x866532},
		{true,  false, 0x866532},
		{true,  false, 0x866532},
		{true,  false, 0x866532},
		{true,  false, 0x866532},
		{true,  false, 0x866532},
		{true,  false, 0x866532},
		{true,  false, 0x866532},
		{true,  false, 0x866532},
		{true,  false, 0x866532},
		{true,  false, 0x866532},
		{true,  false, 0x866532},
		{true,  false, 0x866532},
		{true,  false, 0x866532},
		{true,  false, 0x866532},
		{true,  false, 0x866532},
	},
	{ /* 65 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 66 */
		{true,  false, 0x796c58},
		{true,  false, 0x796c58},
		{true,  false, 0x796c58},
		{true,  false, 0x796c58},
		{true,  false, 0x796c58},
		{true,  false, 0x796c58},
		{true,  false, 0x796c58},
		{true,  false, 0x796c58},
		{true,  false, 0x796c58},
		{true,  false, 0x796c58},
		{true,  false, 0x796c58},
		{true,  false, 0x796c58},
		{true,  false, 0x796c58},
		{true,  false, 0x796c58},
		{true,  false, 0x796c58},
		{true,  false, 0x796c58},
	},
	{ /* 67 */
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
	},
	{ /* 68 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 69 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 70 */
		{true,  false, 0x7d7d7d},
		{true,  false, 0x7d7d7d},
		{true,  false, 0x7d7d7d},
		{true,  false, 0x7d7d7d},
		{true,  false, 0x7d7d7d},
		{true,  false, 0x7d7d7d},
		{true,  false, 0x7d7d7d},
		{true,  false, 0x7d7d7d},
		{true,  false, 0x7d7d7d},
		{true,  false, 0x7d7d7d},
		{true,  false, 0x7d7d7d},
		{true,  false, 0x7d7d7d},
		{true,  false, 0x7d7d7d},
		{true,  false, 0x7d7d7d},
		{true,  false, 0x7d7d7d},
		{true,  false, 0x7d7d7d},
	},
	{ /* 71 */
		{true,  false, 0xa3a3a3},
		{true,  false, 0xa3a3a3},
		{true,  false, 0xa3a3a3},
		{true,  false, 0xa3a3a3},
		{true,  false, 0xa3a3a3},
		{true,  false, 0xa3a3a3},
		{true,  false, 0xa3a3a3},
		{true,  false, 0xa3a3a3},
		{true,  false, 0xa3a3a3},
		{true,  false, 0xa3a3a3},
		{true,  false, 0xa3a3a3},
		{true,  false, 0xa3a3a3},
		{true,  false, 0xa3a3a3},
		{true,  false, 0xa3a3a3},
		{true,  false, 0xa3a3a3},
		{true,  false, 0xa3a3a3},
	},
	{ /* 72 */
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
	},
	{ /* 73 */
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
	},
	{ /* 74 */
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
		{true,  false, 0x846b6b},
	},
	{ /* 75 */
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
	},
	{ /* 76 */
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
	},
	{ /* 77 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 78 */
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
	},
	{ /* 79 */
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
	},
	{ /* 80 */
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
		{true,  false, 0xeffbfb},
	},
	{ /* 81 */
		{true,  false, 0x0d6318},
		{true,  false, 0x0d6318},
		{true,  false, 0x0d6318},
		{true,  false, 0x0d6318},
		{true,  false, 0x0d6318},
		{true,  false, 0x0d6318},
		{true,  false, 0x0d6318},
		{true,  false, 0x0d6318},
		{true,  false, 0x0d6318},
		{true,  false, 0x0d6318},
		{true,  false, 0x0d6318},
		{true,  false, 0x0d6318},
		{true,  false, 0x0d6318},
		{true,  false, 0x0d6318},
		{true,  false, 0x0d6318},
		{true,  false, 0x0d6318},
	},
	{ /* 82 */
		{true,  false, 0x9ea4b0},
		{true,  false, 0x9ea4b0},
		{true,  false, 0x9ea4b0},
		{true,  false, 0x9ea4b0},
		{true,  false, 0x9ea4b0},
		{true,  false, 0x9ea4b0},
		{true,  false, 0x9ea4b0},
		{true,  false, 0x9ea4b0},
		{true,  false, 0x9ea4b0},
		{true,  false, 0x9ea4b0},
		{true,  false, 0x9ea4b0},
		{true,  false, 0x9ea4b0},
		{true,  false, 0x9ea4b0},
		{true,  false, 0x9ea4b0},
		{true,  false, 0x9ea4b0},
		{true,  false, 0x9ea4b0},
	},
	{ /* 83 */
		{true,  false, 0x94c065},
		{true,  false, 0x94c065},
		{true,  false, 0x94c065},
		{true,  false, 0x94c065},
		{true,  false, 0x94c065},
		{true,  false, 0x94c065},
		{true,  false, 0x94c065},
		{true,  false, 0x94c065},
		{true,  false, 0x94c065},
		{true,  false, 0x94c065},
		{true,  false, 0x94c065},
		{true,  false, 0x94c065},
		{true,  false, 0x94c065},
		{true,  false, 0x94c065},
		{true,  false, 0x94c065},
		{true,  false, 0x94c065},
	},
	{ /* 84 */
		{true,  false, 0x6b4937},
		{true,  false, 0x6b4937},
		{true,  false, 0x6b4937},
		{true,  false, 0x6b4937},
		{true,  false, 0x6b4937},
		{true,  false, 0x6b4937},
		{true,  false, 0x6b4937},
		{true,  false, 0x6b4937},
		{true,  false, 0x6b4937},
		{true,  false, 0x6b4937},
		{true,  false, 0x6b4937},
		{true,  false, 0x6b4937},
		{true,  false, 0x6b4937},
		{true,  false, 0x6b4937},
		{true,  false, 0x6b4937},
		{true,  false, 0x6b4937},
	},
	{ /* 85 */
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
	},
	{ /* 86 */
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
	},
	{ /* 87 */
		{true,  false, 0x6f3634},
		{true,  false, 0x6f3634},
		{true,  false, 0x6f3634},
		{true,  false, 0x6f3634},
		{true,  false, 0x6f3634},
		{true,  false, 0x6f3634},
		{true,  false, 0x6f3634},
		{true,  false, 0x6f3634},
		{true,  false, 0x6f3634},
		{true,  false, 0x6f3634},
		{true,  false, 0x6f3634},
		{true,  false, 0x6f3634},
		{true,  false, 0x6f3634},
		{true,  false, 0x6f3634},
		{true,  false, 0x6f3634},
		{true,  false, 0x6f3634},
	},
	{ /* 88 */
		{true,  false, 0x544033},
		{true,  false, 0x544033},
		{true,  false, 0x544033},
		{true,  false, 0x544033},
		{true,  false, 0x544033},
		{true,  false, 0x544033},
		{true,  false, 0x544033},
		{true,  false, 0x544033},
		{true,  false, 0x544033},
		{true,  false, 0x544033},
		{true,  false, 0x544033},
		{true,  false, 0x544033},
		{true,  false, 0x544033},
		{true,  false, 0x544033},
		{true,  false, 0x544033},
		{true,  false, 0x544033},
	},
	{ /* 89 */
		{true,  false, 0x8f7645},
		{true,  false, 0x8f7645},
		{true,  false, 0x8f7645},
		{true,  false, 0x8f7645},
		{true,  false, 0x8f7645},
		{true,  false, 0x8f7645},
		{true,  false, 0x8f7645},
		{true,  false, 0x8f7645},
		{true,  false, 0x8f7645},
		{true,  false, 0x8f7645},
		{true,  false, 0x8f7645},
		{true,  false, 0x8f7645},
		{true,  false, 0x8f7645},
		{true,  false, 0x8f7645},
		{true,  false, 0x8f7645},
		{true,  false, 0x8f7645},
	},
	{ /* 90 */
		{true,  false, 0x570abf},
		{true,  false, 0x570abf},
		{true,  false, 0x570abf},
		{true,  false, 0x570abf},
		{true,  false, 0x570abf},
		{true,  false, 0x570abf},
		{true,  false, 0x570abf},
		{true,  false, 0x570abf},
		{true,  false, 0x570abf},
		{true,  false, 0x570abf},
		{true,  false, 0x570abf},
		{true,  false, 0x570abf},
		{true,  false, 0x570abf},
		{true,  false, 0x570abf},
		{true,  false, 0x570abf},
		{true,  false, 0x570abf},
	},
	{ /* 91 */
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
		{true,  false, 0xc07615},
	},
	{ /* 92 */
		{true,  false, 0xe4cdce},
		{true,  false, 0xe4cdce},
		{true,  false, 0xe4cdce},
		{true,  false, 0xe4cdce},
		{true,  false, 0xe4cdce},
		{true,  false, 0xe4cdce},
		{true,  false, 0xe4cdce},
		{true,  false, 0xe4cdce},
		{true,  false, 0xe4cdce},
		{true,  false, 0xe4cdce},
		{true,  false, 0xe4cdce},
		{true,  false, 0xe4cdce},
		{true,  false, 0xe4cdce},
		{true,  false, 0xe4cdce},
		{true,  false, 0xe4cdce},
		{true,  false, 0xe4cdce},
	},
	{ /* 93 */
		{true,  false, 0x979393},
		{true,  false, 0x979393},
		{true,  false, 0x979393},
		{true,  false, 0x979393},
		{true,  false, 0x979393},
		{true,  false, 0x979393},
		{true,  false, 0x979393},
		{true,  false, 0x979393},
		{true,  false, 0x979393},
		{true,  false, 0x979393},
		{true,  false, 0x979393},
		{true,  false, 0x979393},
		{true,  false, 0x979393},
		{true,  false, 0x979393},
		{true,  false, 0x979393},
		{true,  false, 0x979393},
	},
	{ /* 94 */
		{true,  false, 0xa09393},
		{true,  false, 0xa09393},
		{true,  false, 0xa09393},
		{true,  false, 0xa09393},
		{true,  false, 0xa09393},
		{true,  false, 0xa09393},
		{true,  false, 0xa09393},
		{true,  false, 0xa09393},
		{true,  false, 0xa09393},
		{true,  false, 0xa09393},
		{true,  false, 0xa09393},
		{true,  false, 0xa09393},
		{true,  false, 0xa09393},
		{true,  false, 0xa09393},
		{true,  false, 0xa09393},
		{true,  false, 0xa09393},
	},
	{ /* 95 */
		{true,  false, 0xffffff},
		{true,  false, 0xd87f33},
		{true,  false, 0xb24cd8},
		{true,  false, 0x6699d8},
		{true,  false, 0xe5e533},
		{true,  false, 0x7fcc19},
		{true,  false, 0xf27fa5},
		{true,  false, 0x4c4c4c},
		{true,  false, 0x999999},
		{true,  false, 0x4c7f99},
		{true,  false, 0x7f3fb2},
		{true,  false, 0x334cb2},
		{true,  false, 0x664c33},
		{true,  false, 0x667f33},
		{true,  false, 0x993333},
		{true,  false, 0x191919},
	},
	{ /* 96 */
		{true,  false, 0x7e5d2d},
		{true,  false, 0x7e5d2d},
		{true,  false, 0x7e5d2d},
		{true,  false, 0x7e5d2d},
		{true,  false, 0x7e5d2d},
		{true,  false, 0x7e5d2d},
		{true,  false, 0x7e5d2d},
		{true,  false, 0x7e5d2d},
		{true,  false, 0x7e5d2d},
		{true,  false, 0x7e5d2d},
		{true,  false, 0x7e5d2d},
		{true,  false, 0x7e5d2d},
		{true,  false, 0x7e5d2d},
		{true,  false, 0x7e5d2d},
		{true,  false, 0x7e5d2d},
		{true,  false, 0x7e5d2d},
	},
	{ /* 97 */
		{true,  false, 0x7d7d7d},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x72776a},
		{true,  false, 0x767676},
		{true,  false, 0x767676},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 98 */
		{true,  false, 0x7a7a7a},
		{true,  false, 0x72776a},
		{true,  false, 0x767676},
		{true,  false, 0x767676},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 99 */
		{true,  false, 0x8d6a53},
		{true,  false, 0x8d6a53},
		{true,  false, 0x8d6a53},
		{true,  false, 0x8d6a53},
		{true,  false, 0x8d6a53},
		{true,  false, 0x8d6a53},
		{true,  false, 0x8d6a53},
		{true,  false, 0x8d6a53},
		{true,  false, 0x8d6a53},
		{true,  false, 0x8d6a53},
		{true,  false, 0x8d6a53},
		{true,  false, 0x8d6a53},
		{true,  false, 0x8d6a53},
		{true,  false, 0x8d6a53},
		{true,  false, 0x8d6a53},
		{true,  false, 0x8d6a53},
	},
	{ /* 100 */
		{true,  false, 0xb62524},
		{true,  false, 0xb62524},
		{true,  false, 0xb62524},
		{true,  false, 0xb62524},
		{true,  false, 0xb62524},
		{true,  false, 0xb62524},
		{true,  false, 0xb62524},
		{true,  false, 0xb62524},
		{true,  false, 0xb62524},
		{true,  false, 0xb62524},
		{true,  false, 0xb62524},
		{true,  false, 0xb62524},
		{true,  false, 0xb62524},
		{true,  false, 0xb62524},
		{true,  false, 0xb62524},
		{true,  false, 0xb62524},
	},
	{ /* 101 */
		{true,  false, 0x6d6c6a},
		{true,  false, 0x6d6c6a},
		{true,  false, 0x6d6c6a},
		{true,  false, 0x6d6c6a},
		{true,  false, 0x6d6c6a},
		{true,  false, 0x6d6c6a},
		{true,  false, 0x6d6c6a},
		{true,  false, 0x6d6c6a},
		{true,  false, 0x6d6c6a},
		{true,  false, 0x6d6c6a},
		{true,  false, 0x6d6c6a},
		{true,  false, 0x6d6c6a},
		{true,  false, 0x6d6c6a},
		{true,  false, 0x6d6c6a},
		{true,  false, 0x6d6c6a},
		{true,  false, 0x6d6c6a},
	},
	{ /* 102 */
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
		{true,  false, 0xdaf0f4},
	},
	{ /* 103 */
		{true,  false, 0x979924},
		{true,  false, 0x979924},
		{true,  false, 0x979924},
		{true,  false, 0x979924},
		{true,  false, 0x979924},
		{true,  false, 0x979924},
		{true,  false, 0x979924},
		{true,  false, 0x979924},
		{true,  false, 0x979924},
		{true,  false, 0x979924},
		{true,  false, 0x979924},
		{true,  false, 0x979924},
		{true,  false, 0x979924},
		{true,  false, 0x979924},
		{true,  false, 0x979924},
		{true,  false, 0x979924},
	},
	{ /* 104 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 105 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 106 */
		{true,  true,  0x6f6f6f},
		{true,  true,  0x6f6f6f},
		{true,  true,  0x6f6f6f},
		{true,  true,  0x6f6f6f},
		{true,  true,  0x6f6f6f},
		{true,  true,  0x6f6f6f},
		{true,  true,  0x6f6f6f},
		{true,  true,  0x6f6f6f},
		{true,  true,  0x6f6f6f},
		{true,  true,  0x6f6f6f},
		{true,  true,  0x6f6f6f},
		{true,  true,  0x6f6f6f},
		{true,  true,  0x6f6f6f},
		{true,  true,  0x6f6f6f},
		{true,  true,  0x6f6f6f},
		{true,  true,  0x6f6f6f},
	},
	{ /* 107 */
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
	},
	{ /* 108 */
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
		{true,  false, 0x926356},
	},
	{ /* 109 */
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
		{true,  false, 0x7a7a7a},
	},
	{ /* 110 */
		{true,  false, 0x6f6369},
		{true,  false, 0x6f6369},
		{true,  false, 0x6f6369},
		{true,  false, 0x6f6369},
		{true,  false, 0x6f6369},
		{true,  false, 0x6f6369},
		{true,  false, 0x6f6369},
		{true,  false, 0x6f6369},
		{true,  false, 0x6f6369},
		{true,  false, 0x6f6369},
		{true,  false, 0x6f6369},
		{true,  false, 0x6f6369},
		{true,  false, 0x6f6369},
		{true,  false, 0x6f6369},
		{true,  false, 0x6f6369},
		{true,  false, 0x6f6369},
	},
	{ /* 111 */
		{true,  true,  0x767676},
		{true,  true,  0x767676},
		{true,  true,  0x767676},
		{true,  true,  0x767676},
		{true,  true,  0x767676},
		{true,  true,  0x767676},
		{true,  true,  0x767676},
		{true,  true,  0x767676},
		{true,  true,  0x767676},
		{true,  true,  0x767676},
		{true,  true,  0x767676},
		{true,  true,  0x767676},
		{true,  true,  0x767676},
		{true,  true,  0x767676},
		{true,  true,  0x767676},
		{true,  true,  0x767676},
	},
	{ /* 112 */
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
	},
	{ /* 113 */
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
	},
	{ /* 114 */
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
		{true,  false, 0x2c161a},
	},
	{ /* 115 */
		{true,  false, 0x6a0e1e},
		{true,  false, 0x6c0f16},
		{true,  false, 0x6c0f16},
		{true,  false, 0x6f1211},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 116 */
		{true,  false, 0x67403b},
		{true,  false, 0x67403b},
		{true,  false, 0x67403b},
		{true,  false, 0x67403b},
		{true,  false, 0x67403b},
		{true,  false, 0x67403b},
		{true,  false, 0x67403b},
		{true,  false, 0x67403b},
		{true,  false, 0x67403b},
		{true,  false, 0x67403b},
		{true,  false, 0x67403b},
		{true,  false, 0x67403b},
		{true,  false, 0x67403b},
		{true,  false, 0x67403b},
		{true,  false, 0x67403b},
		{true,  false, 0x67403b},
	},
	{ /* 117 */
		{true,  false, 0x6a6a6a},
		{true,  false, 0x6a6a6a},
		{true,  false, 0x6a6a6a},
		{true,  false, 0x6a6a6a},
		{true,  false, 0x6a6a6a},
		{true,  false, 0x6a6a6a},
		{true,  false, 0x6a6a6a},
		{true,  false, 0x6a6a6a},
		{true,  false, 0x6a6a6a},
		{true,  false, 0x6a6a6a},
		{true,  false, 0x6a6a6a},
		{true,  false, 0x6a6a6a},
		{true,  false, 0x6a6a6a},
		{true,  false, 0x6a6a6a},
		{true,  false, 0x6a6a6a},
		{true,  false, 0x6a6a6a},
	},
	{ /* 118 */
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
	},
	{ /* 119 */
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
	},
	{ /* 120 */
		{true,  false, 0x597560},
		{true,  false, 0x597560},
		{true,  false, 0x597560},
		{true,  false, 0x597560},
		{true,  false, 0x597560},
		{true,  false, 0x597560},
		{true,  false, 0x597560},
		{true,  false, 0x597560},
		{true,  false, 0x597560},
		{true,  false, 0x597560},
		{true,  false, 0x597560},
		{true,  false, 0x597560},
		{true,  false, 0x597560},
		{true,  false, 0x597560},
		{true,  false, 0x597560},
		{true,  false, 0x597560},
	},
	{ /* 121 */
		{true,  false, 0xdddfa5},
		{true,  false, 0xdddfa5},
		{true,  false, 0xdddfa5},
		{true,  false, 0xdddfa5},
		{true,  false, 0xdddfa5},
		{true,  false, 0xdddfa5},
		{true,  false, 0xdddfa5},
		{true,  false, 0xdddfa5},
		{true,  false, 0xdddfa5},
		{true,  false, 0xdddfa5},
		{true,  false, 0xdddfa5},
		{true,  false, 0xdddfa5},
		{true,  false, 0xdddfa5},
		{true,  false, 0xdddfa5},
		{true,  false, 0xdddfa5},
		{true,  false, 0xdddfa5},
	},
	{ /* 122 */
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
	},
	{ /* 123 */
		{true,  false, 0x462b1a},
		{true,  false, 0x462b1a},
		{true,  false, 0x462b1a},
		{true,  false, 0x462b1a},
		{true,  false, 0x462b1a},
		{true,  false, 0x462b1a},
		{true,  false, 0x462b1a},
		{true,  false, 0x462b1a},
		{true,  false, 0x462b1a},
		{true,  false, 0x462b1a},
		{true,  false, 0x462b1a},
		{true,  false, 0x462b1a},
		{true,  false, 0x462b1a},
		{true,  false, 0x462b1a},
		{true,  false, 0x462b1a},
		{true,  false, 0x462b1a},
	},
	{ /* 124 */
		{true,  false, 0x775937},
		{true,  false, 0x775937},
		{true,  false, 0x775937},
		{true,  false, 0x775937},
		{true,  false, 0x775937},
		{true,  false, 0x775937},
		{true,  false, 0x775937},
		{true,  false, 0x775937},
		{true,  false, 0x775937},
		{true,  false, 0x775937},
		{true,  false, 0x775937},
		{true,  false, 0x775937},
		{true,  false, 0x775937},
		{true,  false, 0x775937},
		{true,  false, 0x775937},
		{true,  false, 0x775937},
	},
	{ /* 125 */
		{true,  false, 0x9c7f4e},
		{true,  false, 0x674d2e},
		{true,  false, 0xc3b37b},
		{true,  false, 0x9a6e4d},
		{true,  false, 0xa95b33},
		{true,  false, 0x3d2712},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 126 */
		{true,  false, 0x9c7f4e},
		{true,  false, 0x674d2e},
		{true,  false, 0xc3b37b},
		{true,  false, 0x9a6e4d},
		{true,  false, 0xa95b33},
		{true,  false, 0x3d2712},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x674d2e},
		{true,  false, 0xc3b37b},
		{true,  false, 0x9a6e4d},
		{true,  false, 0xa95b33},
		{true,  false, 0x3d2712},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 127 */
		{true,  false, 0x8a8c40},
		{true,  false, 0x8a8c40},
		{true,  false, 0x8a8c40},
		{true,  false, 0x8a8c40},
		{true,  false, 0x896b33},
		{true,  false, 0x896b33},
		{true,  false, 0x896b33},
		{true,  false, 0x896b33},
		{true,  false, 0x91501e},
		{true,  false, 0x91501e},
		{true,  false, 0x91501e},
		{true,  false, 0x91501e},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 128 */
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
		{true,  false, 0xdad29e},
	},
	{ /* 129 */
		{true,  false, 0x6d8074},
		{true,  false, 0x6d8074},
		{true,  false, 0x6d8074},
		{true,  false, 0x6d8074},
		{true,  false, 0x6d8074},
		{true,  false, 0x6d8074},
		{true,  false, 0x6d8074},
		{true,  false, 0x6d8074},
		{true,  false, 0x6d8074},
		{true,  false, 0x6d8074},
		{true,  false, 0x6d8074},
		{true,  false, 0x6d8074},
		{true,  false, 0x6d8074},
		{true,  false, 0x6d8074},
		{true,  false, 0x6d8074},
		{true,  false, 0x6d8074},
	},
	{ /* 130 */
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
		{true,  false, 0x0c090f},
	},
	{ /* 131 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 132 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 133 */
		{true,  false, 0x51d975},
		{true,  false, 0x51d975},
		{true,  false, 0x51d975},
		{true,  false, 0x51d975},
		{true,  false, 0x51d975},
		{true,  false, 0x51d975},
		{true,  false, 0x51d975},
		{true,  false, 0x51d975},
		{true,  false, 0x51d975},
		{true,  false, 0x51d975},
		{true,  false, 0x51d975},
		{true,  false, 0x51d975},
		{true,  false, 0x51d975},
		{true,  false, 0x51d975},
		{true,  false, 0x51d975},
		{true,  false, 0x51d975},
	},
	{ /* 134 */
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
	},
	{ /* 135 */
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
	},
	{ /* 136 */
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
	},
	{ /* 137 */
		{true,  false, 0xac846c},
		{true,  false, 0xac846c},
		{true,  false, 0xac846c},
		{true,  false, 0xac846c},
		{true,  false, 0xac846c},
		{true,  false, 0xac846c},
		{true,  false, 0xac846c},
		{true,  false, 0xac846c},
		{true,  false, 0xac846c},
		{true,  false, 0xac846c},
		{true,  false, 0xac846c},
		{true,  false, 0xac846c},
		{true,  false, 0xac846c},
		{true,  false, 0xac846c},
		{true,  false, 0xac846c},
		{true,  false, 0xac846c},
	},
	{ /* 138 */
		{true,  false, 0x74ddd7},
		{true,  false, 0x74ddd7},
		{true,  false, 0x74ddd7},
		{true,  false, 0x74ddd7},
		{true,  false, 0x74ddd7},
		{true,  false, 0x74ddd7},
		{true,  false, 0x74ddd7},
		{true,  false, 0x74ddd7},
		{true,  false, 0x74ddd7},
		{true,  false, 0x74ddd7},
		{true,  false, 0x74ddd7},
		{true,  false, 0x74ddd7},
		{true,  false, 0x74ddd7},
		{true,  false, 0x74ddd7},
		{true,  false, 0x74ddd7},
		{true,  false, 0x74ddd7},
	},
	{ /* 139 */
		{true,  false, 0x7a7a7a},
		{true,  false, 0x677967},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 140 */
		{true,  false, 0x764133},
		{true,  false, 0x764133},
		{true,  false, 0x764133},
		{true,  false, 0x764133},
		{true,  false, 0x764133},
		{true,  false, 0x764133},
		{true,  false, 0x764133},
		{true,  false, 0x764133},
		{true,  false, 0x764133},
		{true,  false, 0x764133},
		{true,  false, 0x764133},
		{true,  false, 0x764133},
		{true,  false, 0x764133},
		{true,  false, 0x764133},
		{true,  false, 0x764133},
		{true,  false, 0x764133},
	},
	{ /* 141 */
		{true,  false, 0x01ab10},
		{true,  false, 0x01ab10},
		{true,  false, 0x01bb0f},
		{true,  false, 0x01bb0f},
		{true,  false, 0x00be10},
		{true,  false, 0x00be10},
		{true,  false, 0x158002},
		{true,  false, 0x158002},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 142 */
		{true,  false, 0x01ab10},
		{true,  false, 0x01ab10},
		{true,  false, 0x01bb0f},
		{true,  false, 0x01bb0f},
		{true,  false, 0x00be10},
		{true,  false, 0x00be10},
		{true,  false, 0x22aa24},
		{true,  false, 0x22aa24},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 143 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 144 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 145 */
		{true,  false, 0x403c3c},
		{true,  false, 0x403c3c},
		{true,  false, 0x403c3c},
		{true,  false, 0x403c3c},
		{true,  false, 0x403c3c},
		{true,  false, 0x403c3c},
		{true,  false, 0x403c3c},
		{true,  false, 0x403c3c},
		{true,  false, 0x403c3c},
		{true,  false, 0x403c3c},
		{true,  false, 0x403c3c},
		{true,  false, 0x403c3c},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 146 */
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
		{true,  false, 0x9c7f4e},
	},
	{ /* 147 */
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
		{true,  false, 0xf9ec4e},
	},
	{ /* 148 */
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
		{true,  false, 0xdbdbdb},
	},
	{ /* 149 */
		{true,  false, 0x9c9695},
		{true,  false, 0x9c9695},
		{true,  false, 0x9c9695},
		{true,  false, 0x9c9695},
		{true,  false, 0x9c9695},
		{true,  false, 0x9c9695},
		{true,  false, 0x9c9695},
		{true,  false, 0x9c9695},
		{true,  false, 0x9c9695},
		{true,  false, 0x9c9695},
		{true,  false, 0x9c9695},
		{true,  false, 0x9c9695},
		{true,  false, 0x9c9695},
		{true,  false, 0x9c9695},
		{true,  false, 0x9c9695},
		{true,  false, 0x9c9695},
	},
	{ /* 150 */
		{true,  false, 0xa59594},
		{true,  false, 0xa59594},
		{true,  false, 0xa59594},
		{true,  false, 0xa59594},
		{true,  false, 0xa59594},
		{true,  false, 0xa59594},
		{true,  false, 0xa59594},
		{true,  false, 0xa59594},
		{true,  false, 0xa59594},
		{true,  false, 0xa59594},
		{true,  false, 0xa59594},
		{true,  false, 0xa59594},
		{true,  false, 0xa59594},
		{true,  false, 0xa59594},
		{true,  false, 0xa59594},
		{true,  false, 0xa59594},
	},
	{ /* 151 */
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
	},
	{ /* 152 */
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
		{true,  false, 0xab1b09},
	},
	{ /* 153 */
		{true,  false, 0x7d544f},
		{true,  false, 0x7d544f},
		{true,  false, 0x7d544f},
		{true,  false, 0x7d544f},
		{true,  false, 0x7d544f},
		{true,  false, 0x7d544f},
		{true,  false, 0x7d544f},
		{true,  false, 0x7d544f},
		{true,  false, 0x7d544f},
		{true,  false, 0x7d544f},
		{true,  false, 0x7d544f},
		{true,  false, 0x7d544f},
		{true,  false, 0x7d544f},
		{true,  false, 0x7d544f},
		{true,  false, 0x7d544f},
		{true,  false, 0x7d544f},
	},
	{ /* 154 */
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
		{true,  false, 0x373737},
	},
	{ /* 155 */
		{true,  false, 0xece9e2},
		{true,  false, 0xe7e4db},
		{true,  false, 0xe8e5dd},
		{true,  false, 0xe7e3db},
		{true,  false, 0xe7e3db},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 156 */
		{true,  false, 0xece9e2},
		{true,  false, 0xece9e2},
		{true,  false, 0xece9e2},
		{true,  false, 0xece9e2},
		{true,  false, 0xece9e2},
		{true,  false, 0xece9e2},
		{true,  false, 0xece9e2},
		{true,  false, 0xece9e2},
		{true,  false, 0xece9e2},
		{true,  false, 0xece9e2},
		{true,  false, 0xece9e2},
		{true,  false, 0xece9e2},
		{true,  false, 0xece9e2},
		{true,  false, 0xece9e2},
		{true,  false, 0xece9e2},
		{true,  false, 0xece9e2},
	},
	{ /* 157 */
		{true,  false, 0x685347},
		{true,  false, 0x685347},
		{true,  false, 0x685347},
		{true,  false, 0x685347},
		{true,  false, 0x685347},
		{true,  false, 0x685347},
		{true,  false, 0x685347},
		{true,  false, 0x685347},
		{true,  false, 0x685347},
		{true,  false, 0x685347},
		{true,  false, 0x685347},
		{true,  false, 0x685347},
		{true,  false, 0x685347},
		{true,  false, 0x685347},
		{true,  false, 0x685347},
		{true,  false, 0x685347},
	},
	{ /* 158 */
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
		{true,  false, 0x606060},
	},
	{ /* 159 */
		{true,  false, 0xd1b2a1},
		{true,  false, 0xa15325},
		{true,  false, 0x95586c},
		{true,  false, 0x716c89},
		{true,  false, 0xba8523},
		{true,  false, 0x677534},
		{true,  false, 0xa14e4e},
		{true,  false, 0x392a23},
		{true,  false, 0x876a61},
		{true,  false, 0x565b5b},
		{true,  false, 0x764656},
		{true,  false, 0x4a3b5b},
		{true,  false, 0x4d3323},
		{true,  false, 0x4c532a},
		{true,  false, 0x8f3d2e},
		{true,  false, 0x251610},
	},
	{ /* 160 */
		{true,  false, 0xffffff},
		{true,  false, 0xd87f33},
		{true,  false, 0xb24cd8},
		{true,  false, 0x6699d8},
		{true,  false, 0xe5e533},
		{true,  false, 0x7fcc19},
		{true,  false, 0xf27fa5},
		{true,  false, 0x4c4c4c},
		{true,  false, 0x999999},
		{true,  false, 0x4c7f99},
		{true,  false, 0x7f3fb2},
		{true,  false, 0x334cb2},
		{true,  false, 0x664c33},
		{true,  false, 0x667f33},
		{true,  false, 0x993333},
		{true,  false, 0x191919},
	},
	{ /* 161 */
		{true,  true,  0x878787},
		{true,  true,  0x878787},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{true,  true,  0x878787},
		{true,  true,  0x878787},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{true,  true,  0x878787},
		{true,  true,  0x878787},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{true,  true,  0x878787},
		{true,  true,  0x878787},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 162 */
		{true,  true,  0x9a5b40},
		{true,  true,  0x4e3e29},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{true,  true,  0x696359},
		{true,  true,  0x342817},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{true,  true,  0x696359},
		{true,  true,  0x342817},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{true,  true,  0x696359},
		{true,  true,  0x342817},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 163 */
		{true,  true,  0xa95b33},
		{true,  true,  0xa95b33},
		{true,  true,  0xa95b33},
		{true,  true,  0xa95b33},
		{true,  true,  0xa95b33},
		{true,  true,  0xa95b33},
		{true,  true,  0xa95b33},
		{true,  true,  0xa95b33},
		{true,  true,  0xa95b33},
		{true,  true,  0xa95b33},
		{true,  true,  0xa95b33},
		{true,  true,  0xa95b33},
		{true,  true,  0xa95b33},
		{true,  true,  0xa95b33},
		{true,  true,  0xa95b33},
		{true,  true,  0xa95b33},
	},
	{ /* 164 */
		{true,  true,  0x3d2712},
		{true,  true,  0x3d2712},
		{true,  true,  0x3d2712},
		{true,  true,  0x3d2712},
		{true,  true,  0x3d2712},
		{true,  true,  0x3d2712},
		{true,  true,  0x3d2712},
		{true,  true,  0x3d2712},
		{true,  true,  0x3d2712},
		{true,  true,  0x3d2712},
		{true,  true,  0x3d2712},
		{true,  true,  0x3d2712},
		{true,  true,  0x3d2712},
		{true,  true,  0x3d2712},
		{true,  true,  0x3d2712},
		{true,  true,  0x3d2712},
	},
	{ /* 165 */
		{true,  false, 0x78c865},
		{true,  false, 0x78c865},
		{true,  false, 0x78c865},
		{true,  false, 0x78c865},
		{true,  false, 0x78c865},
		{true,  false, 0x78c865},
		{true,  false, 0x78c865},
		{true,  false, 0x78c865},
		{true,  false, 0x78c865},
		{true,  false, 0x78c865},
		{true,  false, 0x78c865},
		{true,  false, 0x78c865},
		{true,  false, 0x78c865},
		{true,  false, 0x78c865},
		{true,  false, 0x78c865},
		{true,  false, 0x78c865},
	},
	{ /* 166 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 167 */
		{true,  false, 0xc7c7c7},
		{true,  false, 0xc7c7c7},
		{true,  false, 0xc7c7c7},
		{true,  false, 0xc7c7c7},
		{true,  false, 0xc7c7c7},
		{true,  false, 0xc7c7c7},
		{true,  false, 0xc7c7c7},
		{true,  false, 0xc7c7c7},
		{true,  false, 0xc7c7c7},
		{true,  false, 0xc7c7c7},
		{true,  false, 0xc7c7c7},
		{true,  false, 0xc7c7c7},
		{true,  false, 0xc7c7c7},
		{true,  false, 0xc7c7c7},
		{true,  false, 0xc7c7c7},
		{true,  false, 0xc7c7c7},
	},
	{ /* 168 */
		{true,  false, 0x63988d},
		{true,  false, 0x63a08f},
		{true,  false, 0x3b574b},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 169 */
		{true,  false, 0xacc7be},
		{true,  false, 0xacc7be},
		{true,  false, 0xacc7be},
		{true,  false, 0xacc7be},
		{true,  false, 0xacc7be},
		{true,  false, 0xacc7be},
		{true,  false, 0xacc7be},
		{true,  false, 0xacc7be},
		{true,  false, 0xacc7be},
		{true,  false, 0xacc7be},
		{true,  false, 0xacc7be},
		{true,  false, 0xacc7be},
		{true,  false, 0xacc7be},
		{true,  false, 0xacc7be},
		{true,  false, 0xacc7be},
		{true,  false, 0xacc7be},
	},
	{ /* 170 */
		{true,  true,  0xa88b10},
		{true,  true,  0xa88b10},
		{true,  true,  0xa88b10},
		{true,  true,  0xa88b10},
		{true,  true,  0xa88b10},
		{true,  true,  0xa88b10},
		{true,  true,  0xa88b10},
		{true,  true,  0xa88b10},
		{true,  true,  0xa88b10},
		{true,  true,  0xa88b10},
		{true,  true,  0xa88b10},
		{true,  true,  0xa88b10},
		{true,  true,  0xa88b10},
		{true,  true,  0xa88b10},
		{true,  true,  0xa88b10},
		{true,  true,  0xa88b10},
	},
	{ /* 171 */
		{true,  false, 0xe9ecec},
		{true,  false, 0xf07613},
		{true,  false, 0xbd44b3},
		{true,  false, 0x3aafd9},
		{true,  false, 0xf8c527},
		{true,  false, 0x70b919},
		{true,  false, 0xed8dac},
		{true,  false, 0x3e4447},
		{true,  false, 0x8e8e86},
		{true,  false, 0x158991},
		{true,  false, 0x792aac},
		{true,  false, 0x35399d},
		{true,  false, 0x724728},
		{true,  false, 0x546d1b},
		{true,  false, 0xa02722},
		{true,  false, 0x141519},
	},
	{ /* 172 */
		{true,  false, 0x965c42},
		{true,  false, 0x965c42},
		{true,  false, 0x965c42},
		{true,  false, 0x965c42},
		{true,  false, 0x965c42},
		{true,  false, 0x965c42},
		{true,  false, 0x965c42},
		{true,  false, 0x965c42},
		{true,  false, 0x965c42},
		{true,  false, 0x965c42},
		{true,  false, 0x965c42},
		{true,  false, 0x965c42},
		{true,  false, 0x965c42},
		{true,  false, 0x965c42},
		{true,  false, 0x965c42},
		{true,  false, 0x965c42},
	},
	{ /* 173 */
		{true,  false, 0x121212},
		{true,  false, 0x121212},
		{true,  false, 0x121212},
		{true,  false, 0x121212},
		{true,  false, 0x121212},
		{true,  false, 0x121212},
		{true,  false, 0x121212},
		{true,  false, 0x121212},
		{true,  false, 0x121212},
		{true,  false, 0x121212},
		{true,  false, 0x121212},
		{true,  false, 0x121212},
		{true,  false, 0x121212},
		{true,  false, 0x121212},
		{true,  false, 0x121212},
		{true,  false, 0x121212},
	},
	{ /* 174 */
		{true,  false, 0xa5c2f5},
		{true,  false, 0xa5c2f5},
		{true,  false, 0xa5c2f5},
		{true,  false, 0xa5c2f5},
		{true,  false, 0xa5c2f5},
		{true,  false, 0xa5c2f5},
		{true,  false, 0xa5c2f5},
		{true,  false, 0xa5c2f5},
		{true,  false, 0xa5c2f5},
		{true,  false, 0xa5c2f5},
		{true,  false, 0xa5c2f5},
		{true,  false, 0xa5c2f5},
		{true,  false, 0xa5c2f5},
		{true,  false, 0xa5c2f5},
		{true,  false, 0xa5c2f5},
		{true,  false, 0xa5c2f5},
	},
	{ /* 175 */
		{true,  false, 0xeac521},
		{true,  false, 0x94948c},
		{true,  true,  0x929292},
		{true,  true,  0x7d7d7d},
		{true,  false, 0x733d07},
		{true,  false, 0x84858d},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 176 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 177 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 178 */
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
		{true,  false, 0x82745e},
	},
	{ /* 179 */
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
	},
	{ /* 180 */
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
	},
	{ /* 181 */
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
	},
	{ /* 182 */
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
		{true,  false, 0xa6551d},
	},
	{ /* 183 */
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
	},
	{ /* 184 */
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
	},
	{ /* 185 */
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
	},
	{ /* 186 */
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
	},
	{ /* 187 */
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
	},
	{ /* 188 */
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
		{true,  false, 0x674d2e},
	},
	{ /* 189 */
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
		{true,  false, 0xc3b37b},
	},
	{ /* 190 */
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
		{true,  false, 0x9a6e4d},
	},
	{ /* 191 */
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
		{true,  false, 0x3d2712},
	},
	{ /* 192 */
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
		{true,  false, 0xa95b33},
	},
	{ /* 193 */
		{true,  false, 0x614b31},
		{true,  false, 0x614b31},
		{true,  false, 0x614b31},
		{true,  false, 0x614b31},
		{true,  false, 0x614b31},
		{true,  false, 0x614b31},
		{true,  false, 0x614b31},
		{true,  false, 0x614b31},
		{true,  false, 0x614b31},
		{true,  false, 0x614b31},
		{true,  false, 0x614b31},
		{true,  false, 0x614b31},
		{true,  false, 0x614b31},
		{true,  false, 0x614b31},
		{true,  false, 0x614b31},
		{true,  false, 0x614b31},
	},
	{ /* 194 */
		{true,  false, 0xccc28e},
		{true,  false, 0xccc28e},
		{true,  false, 0xccc28e},
		{true,  false, 0xccc28e},
		{true,  false, 0xccc28e},
		{true,  false, 0xccc28e},
		{true,  false, 0xccc28e},
		{true,  false, 0xccc28e},
		{true,  false, 0xccc28e},
		{true,  false, 0xccc28e},
		{true,  false, 0xccc28e},
		{true,  false, 0xccc28e},
		{true,  false, 0xccc28e},
		{true,  false, 0xccc28e},
		{true,  false, 0xccc28e},
		{true,  false, 0xccc28e},
	},
	{ /* 195 */
		{true,  false, 0x966d4e},
		{true,  false, 0x966d4e},
		{true,  false, 0x966d4e},
		{true,  false, 0x966d4e},
		{true,  false, 0x966d4e},
		{true,  false, 0x966d4e},
		{true,  false, 0x966d4e},
		{true,  false, 0x966d4e},
		{true,  false, 0x966d4e},
		{true,  false, 0x966d4e},
		{true,  false, 0x966d4e},
		{true,  false, 0x966d4e},
		{true,  false, 0x966d4e},
		{true,  false, 0x966d4e},
		{true,  false, 0x966d4e},
		{true,  false, 0x966d4e},
	},
	{ /* 196 */
		{true,  false, 0x9b5836},
		{true,  false, 0x9b5836},
		{true,  false, 0x9b5836},
		{true,  false, 0x9b5836},
		{true,  false, 0x9b5836},
		{true,  false, 0x9b5836},
		{true,  false, 0x9b5836},
		{true,  false, 0x9b5836},
		{true,  false, 0x9b5836},
		{true,  false, 0x9b5836},
		{true,  false, 0x9b5836},
		{true,  false, 0x9b5836},
		{true,  false, 0x9b5836},
		{true,  false, 0x9b5836},
		{true,  false, 0x9b5836},
		{true,  false, 0x9b5836},
	},
	{ /* 197 */
		{true,  false, 0x412c17},
		{true,  false, 0x412c17},
		{true,  false, 0x412c17},
		{true,  false, 0x412c17},
		{true,  false, 0x412c17},
		{true,  false, 0x412c17},
		{true,  false, 0x412c17},
		{true,  false, 0x412c17},
		{true,  false, 0x412c17},
		{true,  false, 0x412c17},
		{true,  false, 0x412c17},
		{true,  false, 0x412c17},
		{true,  false, 0x412c17},
		{true,  false, 0x412c17},
		{true,  false, 0x412c17},
		{true,  false, 0x412c17},
	},
	{ /* 198 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 199 */
		{true,  false, 0x603b60},
		{true,  false, 0x603b60},
		{true,  false, 0x603b60},
		{true,  false, 0x603b60},
		{true,  false, 0x603b60},
		{true,  false, 0x603b60},
		{true,  false, 0x603b60},
		{true,  false, 0x603b60},
		{true,  false, 0x603b60},
		{true,  false, 0x603b60},
		{true,  false, 0x603b60},
		{true,  false, 0x603b60},
		{true,  false, 0x603b60},
		{true,  false, 0x603b60},
		{true,  false, 0x603b60},
		{true,  false, 0x603b60},
	},
	{ /* 200 */
		{true,  false, 0x856785},
		{true,  false, 0x856785},
		{true,  false, 0x856785},
		{true,  false, 0x856785},
		{true,  false, 0x856785},
		{true,  false, 0x856785},
		{true,  false, 0x856785},
		{true,  false, 0x856785},
		{true,  false, 0x856785},
		{true,  false, 0x856785},
		{true,  false, 0x856785},
		{true,  false, 0x856785},
		{true,  false, 0x856785},
		{true,  false, 0x856785},
		{true,  false, 0x856785},
		{true,  false, 0x856785},
	},
	{ /* 201 */
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
	},
	{ /* 202 */
		{true,  false, 0xaa80aa},
		{true,  false, 0xaa80aa},
		{true,  false, 0xaa80aa},
		{true,  false, 0xaa80aa},
		{true,  false, 0xaa80aa},
		{true,  false, 0xaa80aa},
		{true,  false, 0xaa80aa},
		{true,  false, 0xaa80aa},
		{true,  false, 0xaa80aa},
		{true,  false, 0xaa80aa},
		{true,  false, 0xaa80aa},
		{true,  false, 0xaa80aa},
		{true,  false, 0xaa80aa},
		{true,  false, 0xaa80aa},
		{true,  false, 0xaa80aa},
		{true,  false, 0xaa80aa},
	},
	{ /* 203 */
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
	},
	{ /* 204 */
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
	},
	{ /* 205 */
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
		{true,  false, 0xa679a6},
	},
	{ /* 206 */
		{true,  false, 0xe1e6aa},
		{true,  false, 0xe1e6aa},
		{true,  false, 0xe1e6aa},
		{true,  false, 0xe1e6aa},
		{true,  false, 0xe1e6aa},
		{true,  false, 0xe1e6aa},
		{true,  false, 0xe1e6aa},
		{true,  false, 0xe1e6aa},
		{true,  false, 0xe1e6aa},
		{true,  false, 0xe1e6aa},
		{true,  false, 0xe1e6aa},
		{true,  false, 0xe1e6aa},
		{true,  false, 0xe1e6aa},
		{true,  false, 0xe1e6aa},
		{true,  false, 0xe1e6aa},
		{true,  false, 0xe1e6aa},
	},
	{ /* 207 */
		{true,  false, 0x01ab10},
		{true,  false, 0x01bb0f},
		{true,  false, 0x00be10},
		{true,  false, 0x507135},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 208 */
		{true,  false, 0x957c47},
		{true,  false, 0x957c47},
		{true,  false, 0x957c47},
		{true,  false, 0x957c47},
		{true,  false, 0x957c47},
		{true,  false, 0x957c47},
		{true,  false, 0x957c47},
		{true,  false, 0x957c47},
		{true,  false, 0x957c47},
		{true,  false, 0x957c47},
		{true,  false, 0x957c47},
		{true,  false, 0x957c47},
		{true,  false, 0x957c47},
		{true,  false, 0x957c47},
		{true,  false, 0x957c47},
		{true,  false, 0x957c47},
	},
	{ /* 209 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 210 */
		{true,  false, 0x7b6bab},
		{true,  false, 0x7b6bab},
		{true,  false, 0x7b6bab},
		{true,  false, 0x7b6bab},
		{true,  false, 0x7b6bab},
		{true,  false, 0x7b6bab},
		{true,  false, 0x7b6bab},
		{true,  false, 0x7b6bab},
		{true,  false, 0x7b6bab},
		{true,  false, 0x7b6bab},
		{true,  false, 0x7b6bab},
		{true,  false, 0x7b6bab},
		{true,  false, 0x7b6bab},
		{true,  false, 0x7b6bab},
		{true,  false, 0x7b6bab},
		{true,  false, 0x7b6bab},
	},
	{ /* 211 */
		{true,  false, 0x819f92},
		{true,  false, 0x819f92},
		{true,  false, 0x819f92},
		{true,  false, 0x819f92},
		{true,  false, 0x819f92},
		{true,  false, 0x819f92},
		{true,  false, 0x819f92},
		{true,  false, 0x819f92},
		{true,  false, 0x819f92},
		{true,  false, 0x819f92},
		{true,  false, 0x819f92},
		{true,  false, 0x819f92},
		{true,  false, 0x819f92},
		{true,  false, 0x819f92},
		{true,  false, 0x819f92},
		{true,  false, 0x819f92},
	},
	{ /* 212 */
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
		{true,  false, 0x7dadff},
	},
	{ /* 213 */
		{true,  false, 0x874119},
		{true,  false, 0x874119},
		{true,  false, 0x874119},
		{true,  false, 0x874119},
		{true,  false, 0x874119},
		{true,  false, 0x874119},
		{true,  false, 0x874119},
		{true,  false, 0x874119},
		{true,  false, 0x874119},
		{true,  false, 0x874119},
		{true,  false, 0x874119},
		{true,  false, 0x874119},
		{true,  false, 0x874119},
		{true,  false, 0x874119},
		{true,  false, 0x874119},
		{true,  false, 0x874119},
	},
	{ /* 214 */
		{true,  false, 0x750607},
		{true,  false, 0x750607},
		{true,  false, 0x750607},
		{true,  false, 0x750607},
		{true,  false, 0x750607},
		{true,  false, 0x750607},
		{true,  false, 0x750607},
		{true,  false, 0x750607},
		{true,  false, 0x750607},
		{true,  false, 0x750607},
		{true,  false, 0x750607},
		{true,  false, 0x750607},
		{true,  false, 0x750607},
		{true,  false, 0x750607},
		{true,  false, 0x750607},
		{true,  false, 0x750607},
	},
	{ /* 215 */
		{true,  false, 0x440406},
		{true,  false, 0x440406},
		{true,  false, 0x440406},
		{true,  false, 0x440406},
		{true,  false, 0x440406},
		{true,  false, 0x440406},
		{true,  false, 0x440406},
		{true,  false, 0x440406},
		{true,  false, 0x440406},
		{true,  false, 0x440406},
		{true,  false, 0x440406},
		{true,  false, 0x440406},
		{true,  false, 0x440406},
		{true,  false, 0x440406},
		{true,  false, 0x440406},
		{true,  false, 0x440406},
	},
	{ /* 216 */
		{true,  false, 0xcdc9b1},
		{true,  false, 0xcdc9b1},
		{true,  false, 0xcdc9b1},
		{true,  false, 0xcdc9b1},
		{true,  false, 0xcdc9b1},
		{true,  false, 0xcdc9b1},
		{true,  false, 0xcdc9b1},
		{true,  false, 0xcdc9b1},
		{true,  false, 0xcdc9b1},
		{true,  false, 0xcdc9b1},
		{true,  false, 0xcdc9b1},
		{true,  false, 0xcdc9b1},
		{true,  false, 0xcdc9b1},
		{true,  false, 0xcdc9b1},
		{true,  false, 0xcdc9b1},
		{true,  false, 0xcdc9b1},
	},
	{ /* 217 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 218 */
		{true,  false, 0x616161},
		{true,  false, 0x616161},
		{true,  false, 0x616161},
		{true,  false, 0x616161},
		{true,  false, 0x616161},
		{true,  false, 0x616161},
		{true,  false, 0x616161},
		{true,  false, 0x616161},
		{true,  false, 0x616161},
		{true,  false, 0x616161},
		{true,  false, 0x616161},
		{true,  false, 0x616161},
		{true,  false, 0x616161},
		{true,  false, 0x616161},
		{true,  false, 0x616161},
		{true,  false, 0x616161},
	},
	{ /* 219 */
		{true,  false, 0xd7dcdd},
		{true,  false, 0xd7dcdd},
		{true,  false, 0xd7dcdd},
		{true,  false, 0xd7dcdd},
		{true,  false, 0xd7dcdd},
		{true,  false, 0xd7dcdd},
		{true,  false, 0xd7dcdd},
		{true,  false, 0xd7dcdd},
		{true,  false, 0xd7dcdd},
		{true,  false, 0xd7dcdd},
		{true,  false, 0xd7dcdd},
		{true,  false, 0xd7dcdd},
		{true,  false, 0xd7dcdd},
		{true,  false, 0xd7dcdd},
		{true,  false, 0xd7dcdd},
		{true,  false, 0xd7dcdd},
	},
	{ /* 220 */
		{true,  false, 0xea6a08},
		{true,  false, 0xea6a08},
		{true,  false, 0xea6a08},
		{true,  false, 0xea6a08},
		{true,  false, 0xea6a08},
		{true,  false, 0xea6a08},
		{true,  false, 0xea6a08},
		{true,  false, 0xea6a08},
		{true,  false, 0xea6a08},
		{true,  false, 0xea6a08},
		{true,  false, 0xea6a08},
		{true,  false, 0xea6a08},
		{true,  false, 0xea6a08},
		{true,  false, 0xea6a08},
		{true,  false, 0xea6a08},
		{true,  false, 0xea6a08},
	},
	{ /* 221 */
		{true,  false, 0xad36a3},
		{true,  false, 0xad36a3},
		{true,  false, 0xad36a3},
		{true,  false, 0xad36a3},
		{true,  false, 0xad36a3},
		{true,  false, 0xad36a3},
		{true,  false, 0xad36a3},
		{true,  false, 0xad36a3},
		{true,  false, 0xad36a3},
		{true,  false, 0xad36a3},
		{true,  false, 0xad36a3},
		{true,  false, 0xad36a3},
		{true,  false, 0xad36a3},
		{true,  false, 0xad36a3},
		{true,  false, 0xad36a3},
		{true,  false, 0xad36a3},
	},
	{ /* 222 */
		{true,  false, 0x31a3d4},
		{true,  false, 0x31a3d4},
		{true,  false, 0x31a3d4},
		{true,  false, 0x31a3d4},
		{true,  false, 0x31a3d4},
		{true,  false, 0x31a3d4},
		{true,  false, 0x31a3d4},
		{true,  false, 0x31a3d4},
		{true,  false, 0x31a3d4},
		{true,  false, 0x31a3d4},
		{true,  false, 0x31a3d4},
		{true,  false, 0x31a3d4},
		{true,  false, 0x31a3d4},
		{true,  false, 0x31a3d4},
		{true,  false, 0x31a3d4},
		{true,  false, 0x31a3d4},
	},
	{ /* 223 */
		{true,  false, 0xf8bc1d},
		{true,  false, 0xf8bc1d},
		{true,  false, 0xf8bc1d},
		{true,  false, 0xf8bc1d},
		{true,  false, 0xf8bc1d},
		{true,  false, 0xf8bc1d},
		{true,  false, 0xf8bc1d},
		{true,  false, 0xf8bc1d},
		{true,  false, 0xf8bc1d},
		{true,  false, 0xf8bc1d},
		{true,  false, 0xf8bc1d},
		{true,  false, 0xf8bc1d},
		{true,  false, 0xf8bc1d},
		{true,  false, 0xf8bc1d},
		{true,  false, 0xf8bc1d},
		{true,  false, 0xf8bc1d},
	},
	{ /* 224 */
		{true,  false, 0x63ac17},
		{true,  false, 0x63ac17},
		{true,  false, 0x63ac17},
		{true,  false, 0x63ac17},
		{true,  false, 0x63ac17},
		{true,  false, 0x63ac17},
		{true,  false, 0x63ac17},
		{true,  false, 0x63ac17},
		{true,  false, 0x63ac17},
		{true,  false, 0x63ac17},
		{true,  false, 0x63ac17},
		{true,  false, 0x63ac17},
		{true,  false, 0x63ac17},
		{true,  false, 0x63ac17},
		{true,  false, 0x63ac17},
		{true,  false, 0x63ac17},
	},
	{ /* 225 */
		{true,  false, 0xe6799d},
		{true,  false, 0xe6799d},
		{true,  false, 0xe6799d},
		{true,  false, 0xe6799d},
		{true,  false, 0xe6799d},
		{true,  false, 0xe6799d},
		{true,  false, 0xe6799d},
		{true,  false, 0xe6799d},
		{true,  false, 0xe6799d},
		{true,  false, 0xe6799d},
		{true,  false, 0xe6799d},
		{true,  false, 0xe6799d},
		{true,  false, 0xe6799d},
		{true,  false, 0xe6799d},
		{true,  false, 0xe6799d},
		{true,  false, 0xe6799d},
	},
	{ /* 226 */
		{true,  false, 0x373a3e},
		{true,  false, 0x373a3e},
		{true,  false, 0x373a3e},
		{true,  false, 0x373a3e},
		{true,  false, 0x373a3e},
		{true,  false, 0x373a3e},
		{true,  false, 0x373a3e},
		{true,  false, 0x373a3e},
		{true,  false, 0x373a3e},
		{true,  false, 0x373a3e},
		{true,  false, 0x373a3e},
		{true,  false, 0x373a3e},
		{true,  false, 0x373a3e},
		{true,  false, 0x373a3e},
		{true,  false, 0x373a3e},
		{true,  false, 0x373a3e},
	},
	{ /* 227 */
		{true,  false, 0x7c7c73},
		{true,  false, 0x7c7c73},
		{true,  false, 0x7c7c73},
		{true,  false, 0x7c7c73},
		{true,  false, 0x7c7c73},
		{true,  false, 0x7c7c73},
		{true,  false, 0x7c7c73},
		{true,  false, 0x7c7c73},
		{true,  false, 0x7c7c73},
		{true,  false, 0x7c7c73},
		{true,  false, 0x7c7c73},
		{true,  false, 0x7c7c73},
		{true,  false, 0x7c7c73},
		{true,  false, 0x7c7c73},
		{true,  false, 0x7c7c73},
		{true,  false, 0x7c7c73},
	},
	{ /* 228 */
		{true,  false, 0x147987},
		{true,  false, 0x147987},
		{true,  false, 0x147987},
		{true,  false, 0x147987},
		{true,  false, 0x147987},
		{true,  false, 0x147987},
		{true,  false, 0x147987},
		{true,  false, 0x147987},
		{true,  false, 0x147987},
		{true,  false, 0x147987},
		{true,  false, 0x147987},
		{true,  false, 0x147987},
		{true,  false, 0x147987},
		{true,  false, 0x147987},
		{true,  false, 0x147987},
		{true,  false, 0x147987},
	},
	{ /* 229 */
		{true,  false, 0x8b608b},
		{true,  false, 0x8b608b},
		{true,  false, 0x8b608b},
		{true,  false, 0x8b608b},
		{true,  false, 0x8b608b},
		{true,  false, 0x8b608b},
		{true,  false, 0x8b608b},
		{true,  false, 0x8b608b},
		{true,  false, 0x8b608b},
		{true,  false, 0x8b608b},
		{true,  false, 0x8b608b},
		{true,  false, 0x8b608b},
		{true,  false, 0x8b608b},
		{true,  false, 0x8b608b},
		{true,  false, 0x8b608b},
		{true,  false, 0x8b608b},
	},
	{ /* 230 */
		{true,  false, 0x2b2d8c},
		{true,  false, 0x2b2d8c},
		{true,  false, 0x2b2d8c},
		{true,  false, 0x2b2d8c},
		{true,  false, 0x2b2d8c},
		{true,  false, 0x2b2d8c},
		{true,  false, 0x2b2d8c},
		{true,  false, 0x2b2d8c},
		{true,  false, 0x2b2d8c},
		{true,  false, 0x2b2d8c},
		{true,  false, 0x2b2d8c},
		{true,  false, 0x2b2d8c},
		{true,  false, 0x2b2d8c},
		{true,  false, 0x2b2d8c},
		{true,  false, 0x2b2d8c},
		{true,  false, 0x2b2d8c},
	},
	{ /* 231 */
		{true,  false, 0x6a4223},
		{true,  false, 0x6a4223},
		{true,  false, 0x6a4223},
		{true,  false, 0x6a4223},
		{true,  false, 0x6a4223},
		{true,  false, 0x6a4223},
		{true,  false, 0x6a4223},
		{true,  false, 0x6a4223},
		{true,  false, 0x6a4223},
		{true,  false, 0x6a4223},
		{true,  false, 0x6a4223},
		{true,  false, 0x6a4223},
		{true,  false, 0x6a4223},
		{true,  false, 0x6a4223},
		{true,  false, 0x6a4223},
		{true,  false, 0x6a4223},
	},
	{ /* 232 */
		{true,  false, 0x4f641f},
		{true,  false, 0x4f641f},
		{true,  false, 0x4f641f},
		{true,  false, 0x4f641f},
		{true,  false, 0x4f641f},
		{true,  false, 0x4f641f},
		{true,  false, 0x4f641f},
		{true,  false, 0x4f641f},
		{true,  false, 0x4f641f},
		{true,  false, 0x4f641f},
		{true,  false, 0x4f641f},
		{true,  false, 0x4f641f},
		{true,  false, 0x4f641f},
		{true,  false, 0x4f641f},
		{true,  false, 0x4f641f},
		{true,  false, 0x4f641f},
	},
	{ /* 233 */
		{true,  false, 0x8c1f1e},
		{true,  false, 0x8c1f1e},
		{true,  false, 0x8c1f1e},
		{true,  false, 0x8c1f1e},
		{true,  false, 0x8c1f1e},
		{true,  false, 0x8c1f1e},
		{true,  false, 0x8c1f1e},
		{true,  false, 0x8c1f1e},
		{true,  false, 0x8c1f1e},
		{true,  false, 0x8c1f1e},
		{true,  false, 0x8c1f1e},
		{true,  false, 0x8c1f1e},
		{true,  false, 0x8c1f1e},
		{true,  false, 0x8c1f1e},
		{true,  false, 0x8c1f1e},
		{true,  false, 0x8c1f1e},
	},
	{ /* 234 */
		{true,  false, 0x19191d},
		{true,  false, 0x19191d},
		{true,  false, 0x19191d},
		{true,  false, 0x19191d},
		{true,  false, 0x19191d},
		{true,  false, 0x19191d},
		{true,  false, 0x19191d},
		{true,  false, 0x19191d},
		{true,  false, 0x19191d},
		{true,  false, 0x19191d},
		{true,  false, 0x19191d},
		{true,  false, 0x19191d},
		{true,  false, 0x19191d},
		{true,  false, 0x19191d},
		{true,  false, 0x19191d},
		{true,  false, 0x19191d},
	},
	{ /* 235 */
		{true,  false, 0xbcd4ca},
		{true,  false, 0xbcd4ca},
		{true,  false, 0xbcd4ca},
		{true,  false, 0xbcd4ca},
		{true,  false, 0xbcd4ca},
		{true,  false, 0xbcd4ca},
		{true,  false, 0xbcd4ca},
		{true,  false, 0xbcd4ca},
		{true,  false, 0xbcd4ca},
		{true,  false, 0xbcd4ca},
		{true,  false, 0xbcd4ca},
		{true,  false, 0xbcd4ca},
		{true,  false, 0xbcd4ca},
		{true,  false, 0xbcd4ca},
		{true,  false, 0xbcd4ca},
		{true,  false, 0xbcd4ca},
	},
	{ /* 236 */
		{true,  false, 0x9a935b},
		{true,  false, 0x9a935b},
		{true,  false, 0x9a935b},
		{true,  false, 0x9a935b},
		{true,  false, 0x9a935b},
		{true,  false, 0x9a935b},
		{true,  false, 0x9a935b},
		{true,  false, 0x9a935b},
		{true,  false, 0x9a935b},
		{true,  false, 0x9a935b},
		{true,  false, 0x9a935b},
		{true,  false, 0x9a935b},
		{true,  false, 0x9a935b},
		{true,  false, 0x9a935b},
		{true,  false, 0x9a935b},
		{true,  false, 0x9a935b},
	},
	{ /* 237 */
		{true,  false, 0xd064bf},
		{true,  false, 0xd064bf},
		{true,  false, 0xd064bf},
		{true,  false, 0xd064bf},
		{true,  false, 0xd064bf},
		{true,  false, 0xd064bf},
		{true,  false, 0xd064bf},
		{true,  false, 0xd064bf},
		{true,  false, 0xd064bf},
		{true,  false, 0xd064bf},
		{true,  false, 0xd064bf},
		{true,  false, 0xd064bf},
		{true,  false, 0xd064bf},
		{true,  false, 0xd064bf},
		{true,  false, 0xd064bf},
		{true,  false, 0xd064bf},
	},
	{ /* 238 */
		{true,  false, 0x5ea4d0},
		{true,  false, 0x5ea4d0},
		{true,  false, 0x5ea4d0},
		{true,  false, 0x5ea4d0},
		{true,  false, 0x5ea4d0},
		{true,  false, 0x5ea4d0},
		{true,  false, 0x5ea4d0},
		{true,  false, 0x5ea4d0},
		{true,  false, 0x5ea4d0},
		{true,  false, 0x5ea4d0},
		{true,  false, 0x5ea4d0},
		{true,  false, 0x5ea4d0},
		{true,  false, 0x5ea4d0},
		{true,  false, 0x5ea4d0},
		{true,  false, 0x5ea4d0},
		{true,  false, 0x5ea4d0},
	},
	{ /* 239 */
		{true,  false, 0xeac058},
		{true,  false, 0xeac058},
		{true,  false, 0xeac058},
		{true,  false, 0xeac058},
		{true,  false, 0xeac058},
		{true,  false, 0xeac058},
		{true,  false, 0xeac058},
		{true,  false, 0xeac058},
		{true,  false, 0xeac058},
		{true,  false, 0xeac058},
		{true,  false, 0xeac058},
		{true,  false, 0xeac058},
		{true,  false, 0xeac058},
		{true,  false, 0xeac058},
		{true,  false, 0xeac058},
		{true,  false, 0xeac058},
	},
	{ /* 240 */
		{true,  false, 0xa2c537},
		{true,  false, 0xa2c537},
		{true,  false, 0xa2c537},
		{true,  false, 0xa2c537},
		{true,  false, 0xa2c537},
		{true,  false, 0xa2c537},
		{true,  false, 0xa2c537},
		{true,  false, 0xa2c537},
		{true,  false, 0xa2c537},
		{true,  false, 0xa2c537},
		{true,  false, 0xa2c537},
		{true,  false, 0xa2c537},
		{true,  false, 0xa2c537},
		{true,  false, 0xa2c537},
		{true,  false, 0xa2c537},
		{true,  false, 0xa2c537},
	},
	{ /* 241 */
		{true,  false, 0xeb9ab5},
		{true,  false, 0xeb9ab5},
		{true,  false, 0xeb9ab5},
		{true,  false, 0xeb9ab5},
		{true,  false, 0xeb9ab5},
		{true,  false, 0xeb9ab5},
		{true,  false, 0xeb9ab5},
		{true,  false, 0xeb9ab5},
		{true,  false, 0xeb9ab5},
		{true,  false, 0xeb9ab5},
		{true,  false, 0xeb9ab5},
		{true,  false, 0xeb9ab5},
		{true,  false, 0xeb9ab5},
		{true,  false, 0xeb9ab5},
		{true,  false, 0xeb9ab5},
		{true,  false, 0xeb9ab5},
	},
	{ /* 242 */
		{true,  false, 0x535a5d},
		{true,  false, 0x535a5d},
		{true,  false, 0x535a5d},
		{true,  false, 0x535a5d},
		{true,  false, 0x535a5d},
		{true,  false, 0x535a5d},
		{true,  false, 0x535a5d},
		{true,  false, 0x535a5d},
		{true,  false, 0x535a5d},
		{true,  false, 0x535a5d},
		{true,  false, 0x535a5d},
		{true,  false, 0x535a5d},
		{true,  false, 0x535a5d},
		{true,  false, 0x535a5d},
		{true,  false, 0x535a5d},
		{true,  false, 0x535a5d},
	},
	{ /* 243 */
		{true,  false, 0x90a6a7},
		{true,  false, 0x90a6a7},
		{true,  false, 0x90a6a7},
		{true,  false, 0x90a6a7},
		{true,  false, 0x90a6a7},
		{true,  false, 0x90a6a7},
		{true,  false, 0x90a6a7},
		{true,  false, 0x90a6a7},
		{true,  false, 0x90a6a7},
		{true,  false, 0x90a6a7},
		{true,  false, 0x90a6a7},
		{true,  false, 0x90a6a7},
		{true,  false, 0x90a6a7},
		{true,  false, 0x90a6a7},
		{true,  false, 0x90a6a7},
		{true,  false, 0x90a6a7},
	},
	{ /* 244 */
		{true,  false, 0x34767d},
		{true,  false, 0x34767d},
		{true,  false, 0x34767d},
		{true,  false, 0x34767d},
		{true,  false, 0x34767d},
		{true,  false, 0x34767d},
		{true,  false, 0x34767d},
		{true,  false, 0x34767d},
		{true,  false, 0x34767d},
		{true,  false, 0x34767d},
		{true,  false, 0x34767d},
		{true,  false, 0x34767d},
		{true,  false, 0x34767d},
		{true,  false, 0x34767d},
		{true,  false, 0x34767d},
		{true,  false, 0x34767d},
	},
	{ /* 245 */
		{true,  false, 0x6d3098},
		{true,  false, 0x6d3098},
		{true,  false, 0x6d3098},
		{true,  false, 0x6d3098},
		{true,  false, 0x6d3098},
		{true,  false, 0x6d3098},
		{true,  false, 0x6d3098},
		{true,  false, 0x6d3098},
		{true,  false, 0x6d3098},
		{true,  false, 0x6d3098},
		{true,  false, 0x6d3098},
		{true,  false, 0x6d3098},
		{true,  false, 0x6d3098},
		{true,  false, 0x6d3098},
		{true,  false, 0x6d3098},
		{true,  false, 0x6d3098},
	},
	{ /* 246 */
		{true,  false, 0x2f408b},
		{true,  false, 0x2f408b},
		{true,  false, 0x2f408b},
		{true,  false, 0x2f408b},
		{true,  false, 0x2f408b},
		{true,  false, 0x2f408b},
		{true,  false, 0x2f408b},
		{true,  false, 0x2f408b},
		{true,  false, 0x2f408b},
		{true,  false, 0x2f408b},
		{true,  false, 0x2f408b},
		{true,  false, 0x2f408b},
		{true,  false, 0x2f408b},
		{true,  false, 0x2f408b},
		{true,  false, 0x2f408b},
		{true,  false, 0x2f408b},
	},
	{ /* 247 */
		{true,  false, 0x776a55},
		{true,  false, 0x776a55},
		{true,  false, 0x776a55},
		{true,  false, 0x776a55},
		{true,  false, 0x776a55},
		{true,  false, 0x776a55},
		{true,  false, 0x776a55},
		{true,  false, 0x776a55},
		{true,  false, 0x776a55},
		{true,  false, 0x776a55},
		{true,  false, 0x776a55},
		{true,  false, 0x776a55},
		{true,  false, 0x776a55},
		{true,  false, 0x776a55},
		{true,  false, 0x776a55},
		{true,  false, 0x776a55},
	},
	{ /* 248 */
		{true,  false, 0x758e43},
		{true,  false, 0x758e43},
		{true,  false, 0x758e43},
		{true,  false, 0x758e43},
		{true,  false, 0x758e43},
		{true,  false, 0x758e43},
		{true,  false, 0x758e43},
		{true,  false, 0x758e43},
		{true,  false, 0x758e43},
		{true,  false, 0x758e43},
		{true,  false, 0x758e43},
		{true,  false, 0x758e43},
		{true,  false, 0x758e43},
		{true,  false, 0x758e43},
		{true,  false, 0x758e43},
		{true,  false, 0x758e43},
	},
	{ /* 249 */
		{true,  false, 0xb53b35},
		{true,  false, 0xb53b35},
		{true,  false, 0xb53b35},
		{true,  false, 0xb53b35},
		{true,  false, 0xb53b35},
		{true,  false, 0xb53b35},
		{true,  false, 0xb53b35},
		{true,  false, 0xb53b35},
		{true,  false, 0xb53b35},
		{true,  false, 0xb53b35},
		{true,  false, 0xb53b35},
		{true,  false, 0xb53b35},
		{true,  false, 0xb53b35},
		{true,  false, 0xb53b35},
		{true,  false, 0xb53b35},
		{true,  false, 0xb53b35},
	},
	{ /* 250 */
		{true,  false, 0x431e20},
		{true,  false, 0x431e20},
		{true,  false, 0x431e20},
		{true,  false, 0x431e20},
		{true,  false, 0x431e20},
		{true,  false, 0x431e20},
		{true,  false, 0x431e20},
		{true,  false, 0x431e20},
		{true,  false, 0x431e20},
		{true,  false, 0x431e20},
		{true,  false, 0x431e20},
		{true,  false, 0x431e20},
		{true,  false, 0x431e20},
		{true,  false, 0x431e20},
		{true,  false, 0x431e20},
		{true,  false, 0x431e20},
	},
	{ /* 251 */
		{true,  false, 0xcfd5d6},
		{true,  false, 0xe06100},
		{true,  false, 0xa9309f},
		{true,  false, 0x2389c6},
		{true,  false, 0xf0af15},
		{true,  false, 0x5ea818},
		{true,  false, 0xd5658e},
		{true,  false, 0x36393d},
		{true,  false, 0x7d7d73},
		{true,  false, 0x157788},
		{true,  false, 0x641f9c},
		{true,  false, 0x2c2e8f},
		{true,  false, 0x603b1f},
		{true,  false, 0x495b24},
		{true,  false, 0x8e2020},
		{true,  false, 0x080a0f},
	},
	{ /* 252 */
		{true,  false, 0xe1e3e3},
		{true,  false, 0xe3831f},
		{true,  false, 0xc053b8},
		{true,  false, 0x4ab4d5},
		{true,  false, 0xe8c736},
		{true,  false, 0x7dbd29},
		{true,  false, 0xe499b5},
		{true,  false, 0x4c5154},
		{true,  false, 0x9a9a94},
		{true,  false, 0x24939d},
		{true,  false, 0x8337b1},
		{true,  false, 0x4649a6},
		{true,  false, 0x7d5435},
		{true,  false, 0x61772c},
		{true,  false, 0xa83632},
		{true,  false, 0x191a1f},
	},
	{ /* 253 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 254 */
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
		{false, false, 0x000000},
	},
	{ /* 255 */
		{true,  false, 0x584a5a},
		{true,  false, 0x584a5a},
		{true,  false, 0x584a5a},
		{true,  false, 0x584a5a},
		{true,  false, 0x584a5a},
		{true,  false, 0x584a5a},
		{true,  false, 0x584a5a},
		{true,  false, 0x584a5a},
		{true,  false, 0x584a5a},
		{true,  false, 0x584a5a},
		{true,  false, 0x584a5a},
		{true,  false, 0x584a5a},
		{true,  false, 0x584a5a},
		{true,  false, 0x584a5a},
		{true,  false, 0x584a5a},
		{true,  false, 0x584a5a},
	},
};

}
}
